@@ -8,6 +8,7 @@ test_that("error when input file does not exist", {
       "PeakSegFPOP_interface",
       bedGraph.file = "foo/bar/sars", 
       penalty = "10.5",
+      db.file=tempfile(),
       PACKAGE = "PeakSegDisk")
   }, "unable to open input file for reading")
 })
@@ -23,9 +24,10 @@ four <- rbind(
 write.table(
   four, tmp <- tempfile(),
   sep="\t", row.names=FALSE, col.names=FALSE)
+db <- tempfile()
+pstr <- "10.5"
 
 test_that("character penalty works", {
-  pstr <- "10.5"
   PeakSegFPOP_file(tmp, pstr)
   segments.bed <- paste0(tmp, "_penalty=", pstr, "_segments.bed")
   seg.df <- read.table(segments.bed)
@@ -45,3 +47,23 @@ test_that("error for numeric penalty", {
   }, "pen.str must be a character string that can be converted to a non-negative numeric scalar")
 })
 
+test_that("specifying temp db is OK", {
+  fit <- PeakSegFPOP_file(tmp, pstr, db)
+  segments.bed <- paste0(tmp, "_penalty=", pstr, "_segments.bed")
+  seg.df <- read.table(segments.bed)
+  names(seg.df) <- c("chrom", "chromStart", "chromEnd", "status", "mean")
+  expect_equal(paste(seg.df$chrom), c("chr1", "chr1", "chr1"))
+  expect_equal(seg.df$chromStart, c(30, 10, 0))
+  expect_equal(seg.df$chromEnd, c(40, 30, 10))
+  expect_equal(paste(seg.df$status), c("background", "peak", "background"))
+  m <- mean(four$coverage[-1])
+  expected.mean <- c(m, m, four$coverage[1])
+  expect_equal(seg.df$mean, expected.mean, tol=1e-3)
+})
+
+test_that("specifying unwritable temp db is an error", {
+  expect_error({
+    PeakSegFPOP_file(tmp, pstr, "foo/bar/sars")
+  }, "unable to write to cost function database file foo/bar/sars")
+})
+
